@@ -10,10 +10,22 @@ function [C,N,LAGS] = xcovf(X,Y,MAXLAG,SCALEOPT)
 % [C,N,LAGS] = xcovf(X,Y,MAXLAG,SCALEOPT);
 %      calculates the crosscorrelation function between X and Y
 %
+%  SCALEOPT   [character string] specifies the type of scaling applied
+%          to the correlation vector (or matrix). is one of:
+%    'none'      return the unscaled correlation, R,
+%    'biased'    return the biased average, R/N, 
+%    'unbiased'  return the unbiassed average, R(k)/(N-|k|), 
+%    'coeff'     return the correlation coefficient, R/(rms(x).rms(y)),
+%          where "k" is the lag, and "N" is the length of X.
+%          If omitted, the default value is "none".
+%          If Y is supplied but does not have the ame length as X,
+%          scale must be "none".
+%
+%
 % see also: COVM, XCORR
 
-%	$Id: xcovf.m 8223 2011-04-20 09:16:06Z schloegl $
-%	Copyright (C) 2005,2010 by Alois Schloegl <alois.schloegl@gmail.com>	
+%	$Id: xcovf.m 9608 2012-02-10 09:56:25Z schloegl $
+%	Copyright (C) 2005,2010,2011 by Alois Schloegl <alois.schloegl@gmail.com>	
 %       This function is part of the NaN-toolbox
 %       http://pub.ist.ac.at/~schloegl/matlab/NaN/
 
@@ -35,9 +47,9 @@ if nargin<2,
         MAXLAG = [];
         SCALEOPT = 'none';
 elseif ischar(Y),
-        SCALEOPT=Y;
+        MAXLAG = Y;
+        SCALEOPT=MAXLAG;
         Y=[];
-        MAXLAG = [];
 elseif all(size(Y)==1),
         if nargin<3
                 SCALEOPT = 'none';
@@ -103,3 +115,4 @@ elseif strcmp(SCALEOPT,'unbiased')
 else
         warning('invalid SCALEOPT - not supported');
 end;
+
