@@ -1,5 +1,4 @@
-//-------------------------------------------------------------------
-#pragma hdrstop
+
 //-------------------------------------------------------------------
 //   C-MEX implementation of SUMSKIPNAN - this function is part of the NaN-toolbox. 
 //
@@ -39,18 +38,18 @@
 // - sums of squares
 //
 //
-//    $Id: sumskipnan_mex.cpp 7487 2010-07-28 09:28:54Z schloegl $
-//    Copyright (C) 2009 Alois Schloegl <a.schloegl@ieee.org>
+//    $Id: sumskipnan_mex.cpp 9061 2011-11-11 07:47:37Z schloegl $
+//    Copyright (C) 2009,2010,2011 Alois Schloegl <alois.schloegl@gmail.com>
 //    This function is part of the NaN-toolbox
-//    http://hci.tugraz.at/~schloegl/matlab/NaN/
+//    http://pub.ist.ac.at/~schloegl/matlab/NaN/
 //
 //-------------------------------------------------------------------
 
 
 
 
-#include <inttypes.h>
 #include <math.h>
+#include <stdint.h>
 #include "mex.h"
 
 inline int __sumskipnan2w__(double *data, size_t Ni, double *s, double *No, char *flag_anyISNAN, double *W);
@@ -174,7 +173,6 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 	POutput[0] = mxCreateNumericArray(ND2, SZ2, TYP, mxREAL);
 	LOutputSum = mxGetPr(POutput[0]);
 	if (D1!=1 && D2>0) LongOutputSum = (long double*) mxCalloc(D1*D3,sizeof(long double));
-
     	if (POutputCount >= 2) {
 		POutput[1] = mxCreateNumericArray(ND2, SZ2, TYP, mxREAL);
 		LOutputCount = mxGetPr(POutput[1]);
@@ -187,95 +185,114 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
     	}
 	mxFree(SZ2);
 
-	if (D1*D2*D3<1) // zero size array
+
+	if (!D1 || !D2 || !D3) // zero size array
 		; 	// do nothing 
-	else if ((D1==1) && (ACC_LEVEL<1)) {
+	else if (D1==1) {
+	    if (ACC_LEVEL<1) {
 		// double accuray, naive summation, error = N*2^-52 
 		switch (POutputCount) {
+		case 0: 
 		case 1: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				double count;
 				__sumskipnan2wr__(LInput+l*D2, D2, LOutputSum+l, &count, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 2: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan2wr__(LInput+l*D2, D2, LOutputSum+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 3: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan3wr__(LInput+l*D2, D2, LOutputSum+l, LOutputSum2+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		}
-	}
-	else if ((D1==1) && (ACC_LEVEL==1)) {
+	    }
+	    else if (ACC_LEVEL==1) {
 		// extended accuray, naive summation, error = N*2^-64 
 		switch (POutputCount) {
+		case 0: 
 		case 1: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				double count;
 				__sumskipnan2w__(LInput+l*D2, D2, LOutputSum+l, &count, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 2: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan2w__(LInput+l*D2, D2, LOutputSum+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 3: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan3w__(LInput+l*D2, D2, LOutputSum+l, LOutputSum2+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		}
-	}
-	else if ((D1==1) && (ACC_LEVEL==3)) {
+	    }
+	    else if (ACC_LEVEL==3) {
 		// ACC_LEVEL==3: extended accuracy and Kahan Summation, error = 2^-64
 		switch (POutputCount) {
+		case 0: 
 		case 1: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				double count;
 				__sumskipnan2we__(LInput+l*D2, D2, LOutputSum+l, &count, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 2: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan2we__(LInput+l*D2, D2, LOutputSum+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 3: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan3we__(LInput+l*D2, D2, LOutputSum+l, LOutputSum2+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		}
-	}
-	else if ((D1==1) && (ACC_LEVEL==2)) {
+	    }
+	    else if (ACC_LEVEL==2) {
 		// ACC_LEVEL==2: double accuracy and Kahan Summation, error = 2^-52
 		switch (POutputCount) {
+		case 0: 
 		case 1: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				double count;
 				__sumskipnan2wer__(LInput+l*D2, D2, LOutputSum+l, &count, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 2: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan2wer__(LInput+l*D2, D2, LOutputSum+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		case 3: 
+			#pragma omp parallel for schedule(dynamic)
 			for (l = 0; l<D3; l++) {
 				__sumskipnan3wer__(LInput+l*D2, D2, LOutputSum+l, LOutputSum2+l, LOutputCount+l, &flag_isNaN, W);
-			} 
+			}
 			break;
 		}
+            }
 	}
 	else if (POutputCount <= 1) {
 		// OUTER LOOP: along dimensions > DIM
-		for (l = 0; l<D3; l++) {
+ 		for (l = 0; l<D3; l++) {
 			ix0 = l*D1; 	// index for output
 			ix1 = ix0*D2;	// index for input 
 			for (j=0; j<D2; j++) {
@@ -408,6 +425,7 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 			}
                	}		
 	}
+
 	if (LongOutputSum) mxFree(LongOutputSum);
 	if (LongOutputCount) mxFree(LongOutputCount);
 	if (LongOutputSum2) mxFree(LongOutputSum2);
@@ -455,7 +473,6 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 #endif
 }
 
-
 #define stride 1 
 inline int __sumskipnan2w__(double *data, size_t Ni, double *s, double *No, char *flag_anyISNAN, double *W)
 {
