@@ -26,7 +26,7 @@
 //   You should have received a copy of the GNU General Public License
 //   along with this program; if not, see <http://www.gnu.org/licenses/>.
 //
-//    $Id: xptopen.cpp 8231 2011-04-22 19:15:29Z schloegl $
+//    $Id: xptopen.cpp 9607 2012-02-10 09:50:15Z schloegl $
 //    Copyright (C) 2010,2011 Alois Schloegl <alois.schloegl@gmail.com>
 //    This function is part of the NaN-toolbox
 //    http://pub.ist.ac.at/~schloegl/matlab/NaN/
@@ -56,6 +56,7 @@ SPSS file format
 #include <stdint.h>
 #include <stdio.h>
 #include <string.h>
+#include <sys/param.h>
 #include <time.h>
 #include "mex.h"
 
@@ -71,7 +72,6 @@ SPSS file format
 #define max(a,b)	(((a) > (b)) ? (a) : (b))
 #define min(a,b)	(((a) < (b)) ? (a) : (b))
 
-
 #ifdef __linux__
 /* use byteswap macros from the host system, hopefully optimized ones ;-) */
 #include <byteswap.h>
@@ -83,6 +83,13 @@ SPSS file format
 #define __BYTE_ORDER __LITTLE_ENDIAN
 #endif
 
+#if (defined(BSD) && (BSD >= 199103))
+#include <machine/endian.h>
+#define __BIG_ENDIAN _BIG_ENDIAN
+#define __LITTLE_ENDIAN _LITTLE_ENDIAN
+#define __BYTE_ORDER _BYTE_ORDER
+#endif
+
 #ifndef _BYTESWAP_H
 /* define our own version - needed for Max OS X*/
 #define bswap_16(x)   \
@@ -144,7 +151,9 @@ SPSS file format
 	The output files can be zipped, too. 
  */
 
+#ifdef WITH_ZLIB
 #include <zlib.h>
+#endif
 
 
 double xpt2d(uint64_t x);
@@ -169,18 +178,18 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 {
 	const char L1[] = "HEADER RECORD*******LIBRARY HEADER RECORD!!!!!!!000000000000000000000000000000  ";
 	const char L2[] = "SAS     SAS     SASLIB 6.06     bsd4.2                          13APR89:10:20:06";
-	const char L3[] = "";
+	//const char L3[] = "";
 	const char L4[] = "HEADER RECORD*******MEMBER  HEADER RECORD!!!!!!!000000000000000001600000000140  ";
 	const char L5[] = "HEADER RECORD*******DSCRPTR HEADER RECORD!!!!!!!000000000000000000000000000000  ";
 	const char L6[] = "SAS     ABC     SASLIB 6.06     bsd4.2                          13APR89:10:20:06";
-	const char L7[] = "";
+	//const char L7[] = "";
 	const char L8[] = "HEADER RECORD*******NAMESTR HEADER RECORD!!!!!!!000000000200000000000000000000  ";
 	const char LO[] = "HEADER RECORD*******OBS     HEADER RECORD!!!!!!!000000000000000000000000000000  ";
 
 	const  char DATEFORMAT[] = "%d%b%y:%H:%M:%S";
 	char   *fn = NULL;
 	char   Mode[3] = "r";
-	size_t count = 0, HeadLen0=80*8, HeadLen2=0, sz2 = 0, M=0;
+	size_t count = 0, HeadLen0=80*8, HeadLen2=0, sz2 = 0;
 	uint32_t NS = 0;
 	char   H0[HeadLen0];
 	char   *H2 = NULL;
@@ -210,7 +219,11 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 		mexPrintf("\n\tX = xptopen(filename)\n");
 		mexPrintf("\tX = xptopen(filename,'r')\n");
 		mexPrintf("\t\tread filename and return variables in struct X\n");
+#ifdef ZLIB_H		
 		mexPrintf("\tSupported are ARFF, SAS-XPT and STATA files with or w/o zlib/gzip compression.\n");
+#else
+		mexPrintf("\tSupported are ARFF, SAS-XPT and STATA files.\n");
+#endif
 		mexPrintf("\n\tX = xptopen(filename,'w',X)\n");
 		mexPrintf("\t\tsave fields of struct X in filename.\n\n");
 		mexPrintf("\tThe fields of X must be column vectors of equal length.\n");
@@ -243,6 +256,8 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
 		/*
 			SPSS file format
 		*/
+                        uint32_t M=0; 
+
 		        mexWarnMsgTxt("XPTOPEN: support of for SPSS file format is very experimental (do not use it for production use)\n");
 
 			TYPE = SPSS;
@@ -364,6 +379,8 @@ if present.
 			http://www.stata.com/help.cgi?dta_113
 			Stata files written by R start with 0x6e
 		*/
+                        uint32_t M=0; 
+
 			TYPE = STATA;
 			// Header 119 bytes
 	    		LittleEndian = H0[1]==2;
@@ -384,7 +401,7 @@ if present.
 			HeadLen2 = fread(H1,1,HeadLen2,fid);
 
 			// expansion fields
-			char typ; int32_t len,c;
+			char typ; int32_t len;
 			char flagSWAP = (((__BYTE_ORDER == __BIG_ENDIAN) && LittleEndian) || ((__BYTE_ORDER == __LITTLE_ENDIAN) && !LittleEndian));
 			do {
 				fread(&typ,1,1,fid);
@@ -414,7 +431,7 @@ if present.
 				case 0xfd: sz = 4; break;
 				case 0xfe: sz = 4; break;
 				case 0xff: sz = 8; break;
-				otherwise: sz = typlist[k];
+				default: sz = typlist[k];
 				}
 				bi[k+1] = bi[k]+sz;
 			}
@@ -500,6 +517,8 @@ if present.
 		/*
 			 ARFF
 		*/
+                        uint32_t M=0; 
+
 			TYPE = ARFF;
 			rewind(fid);
 
@@ -706,6 +725,7 @@ if present.
 		/*
 			 SAS Transport file format (XPORT)
 		*/
+                        size_t M=0; 
 			TYPE = SASXPT;
 
 			/* TODO: sanity checks */
@@ -749,8 +769,8 @@ if present.
 				size_t maxlen = b_endian_u16(*(int16_t*)(H2+k*sz2+4));
 
 				ListOfVarNames[k] = VarNames+pos;
-				int n = k*sz2+8;
-				int flagDate = (!memcmp(H2+n+48,"DATE    ",8) || !memcmp(H2+n+48,"MONNAME ",8));
+				unsigned int n = k*sz2+8;
+				// int flagDate = (!memcmp(H2+n+48,"DATE    ",8) || !memcmp(H2+n+48,"MONNAME ",8)); // not used
 				do {
 					VarNames[pos++] = H2[n];
 				} while (isalnum(H2[++n]) && (n < k*sz2+16));
@@ -969,7 +989,7 @@ double xpt2d(uint64_t x) {
 	mexPrintf("%x %x %016Lx\n",s,e,x);
 #endif
 
-	double y = ldexp(x, e*4-56);
+	double y = ldexp((double)x, e*4-56);
 	if (s) return(-y);
 	else   return( y);
 
@@ -1011,7 +1031,7 @@ uint64_t d2xpt(double x) {
 	*(((char*)&m) + 6) &= 0x0f; //
 	if (e) *(((char*)&m) + 6) |= 0x10; // reconstruct implicit leading '1' for normalized numbers
 	m <<= (3-(-e & 3));
-	*(((char*)&m) + 7)  = s ? 0x80 : 0;
+	*(((uint8_t*)&m) + 7)  = s ? 0x80 : 0;
 	e = (e + (-e & 3)) / 4 + 64;
 
 	if (e >= 128) return(0x5f); // overflow
